@@ -135,11 +135,11 @@ In your C<.dataprinter> file:
 
 You may also customize the look and feel with the following options:
 
-    datetime_filter.show_class_name = 1
-    datetime_filter.show_timezone   = 0
+    filter_datetime.show_class_name = 1
+    filter_datetime.show_timezone   = 0
 
     # you can even customize your themes:
-    color.datetime = #cc7a23
+    colors.datetime = #cc7a23
 
 That's it!
 
